@@ -3,9 +3,6 @@
 dbQuoteIdentifier_DBIConnection <- function(conn, x, ...) {
   # Don't support lists, auto-vectorization violates type stability
   if (is(x, "SQL")) return(x)
-  if (is(x, "Id")) {
-    return(SQL(paste0(dbQuoteIdentifier(conn, x@name), collapse = ".")))
-  }
   if (!is.character(x)) stop("x must be character or SQL", call. = FALSE)
 
   if (any(is.na(x))) {
@@ -37,4 +34,4 @@ setMethod("dbQuoteIdentifier", signature("DBIConnection", "SQL"), dbQuoteIdentif
 
 #' @rdname hidden_aliases
 #' @export
-setMethod("dbQuoteIdentifier", signature("DBIConnection", "Id"), dbQuoteIdentifier_DBIConnection)
+setMethod("dbQuoteIdentifier", signature("DBIConnection", "Id"), dbQuoteIdentifier_DBIConnection_Id)
